/*
 * ftpd/config.c --
 *
 *	A very simple and basic ftp daemon. This file contains the
 *	configuration file parsing functions.
 */

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <ctype.h>
#include <syslog.h>
#include <assert.h>

#include "ftpd.h"

int get_config(const char *filename, const char *key, char **v1, char **v2)
{
    FILE *s;
    char line[BUFLEN];
    char *p, *k;

    assert(filename && key);

    s = fopen(filename, "r");
    if (! s) {
	syslog(LOG_WARNING, "opening config file '%s' failed: %s",
	       filename, strerror(errno));
	return -1;
    }

    while (fgets(line, sizeof(line), s)) {
	p = line;

	/* skipping over white space / comments / empty lines */
	while (*p && isspace(*p)) p++;
	if (! *p || *p == '#') continue;

	/* extracting and checking the key */
	k = strtok(p, ":\n");
	if (! k || strcmp(k, key) != 0) continue;

	/* extracting first value field */
	k = strtok(NULL, ":\n");
	if (k && v1) *v1 = strdup(k);

	/* extracting second value field */
	k = strtok(NULL, ":\n");
	if (k && v2) *v2 = strdup(k);
	break;
    }

    fclose(s);
    return 0;
}
